==> elasticsearch-cambium-1.0.9.tgz: package/index.ts <==
import { Configuration } from "./config";
import ElasticSearchInterface from "./ElasticSearchInterface";
import { ElasticSearchService } from "./services/elastic.service";

export class ElasticSearch implements ElasticSearchInterface<any> {
  //field
  config: Configuration;
  service: any;
  elasticUrl: string;
  index:string
  //constructor
  constructor(config: Configuration = {elasticUrl:'http://localhost:9200/',index:'my-index'}) {
    
    this.config = Object.assign(config);
    this.service = new ElasticSearchService(config.elasticUrl,config.index);
    this.elasticUrl = config?.elasticUrl;
    this.index = config?.index
    
  }
  async search(obj: any) {
    const result = await this.service.search( obj);
    return result;
  }
  async addItem(item: any) {
    const ifExist = await this.service.getByElasticId(item.id)
    if(!ifExist) {
      var id = await this.service.addItem(item);
    }else{
      var id = await this.service.updateItem(item);
    }
    return id;
  }
  async addMultipleItems(array: Array<any>) {
    return await this.service.addMultipleItems(array);
  }
  async updateItem(obj: any) {
    return await this.service.updateItem(obj);
  }
  async searchByField(field:string,value: string) {
    const obj = await this.service.searchByField(field, value);
    return obj;
  }
  async getByElasticId(id: string) {
    const ans = await this.service.getByElasticId(id);
    console.log('ans: ',ans)
    return ans[0];
  }
  async searchByOneOfMultiFields(fields: Array<string>,txt:string){
    const ans = await this.service.searchByOneOfMultiFields(fields,txt);
    console.log('ans2: ',ans)
    return ans[0];
  }
  async deleteByElasticId(id: string) {
    this.service.deleteDocumentByElasticId( id);
  }
  async deleteByField(field: string, value: string|boolean) {
    this.service.deleteByField(field, value);
  }
  async deleteByMultipleFields(deleteObj: any) {
    this.service.deleteByMultipleFields(deleteObj);
  }
}

==> elasticsearch-cambium-1.0.13.tgz: package/index.ts <==
import { nodeModuleNameResolver } from "typescript";
import { Configuration } from "./config";
import ElasticSearchInterface from "./ElasticSearchInterface";
import { ElasticSearchService } from "./services/elastic.service";

export class ElasticSearch implements ElasticSearchInterface<any> {
  //field
  config: Configuration;
  service: any;
  elasticUrl: string;
  index:string
  //constructor
  constructor(config: Configuration = {elasticUrl:'http://localhost:9200/',index:'my-index'}) {
    
    this.config = Object.assign(config);
    this.service = new ElasticSearchService(config.elasticUrl,config.index);
    this.elasticUrl = config?.elasticUrl;
    this.index = config?.index
    
  }
  async search(obj: any,limit:any=null,offset:any=null) {
    const result = await this.service.search(obj,limit,offset);
    console.log('result: ',result)
    return result;
  }
  async addItem(item: any) {
    const ifExist = await this.service.getByElasticId(item.id)
    if(!ifExist) {
      var id = await this.service.addItem(item);
    }else{
      var id = await this.service.updateItem(item);
    }
    return id;
  }
  async addMultipleItems(array: Array<any>) {
    return await this.service.addMultipleItems(array);
  }
  async updateItem(obj: any) {
    return await this.service.updateItem(obj);
  }
  async searchByField(field:string,value: string,limit:any=null,offset:any=null) {
    const obj = await this.service.searchByField(field, value,limit,offset);
    console.log('obj: ',obj)
    return obj;
  }
  async getByElasticId(id: string) {
    const ans = await this.service.getByElasticId(id);
    console.log('ans: ',ans)
    return ans[0];
  }
  async searchByOneOfMultiFields(fields: Array<string>,txt:string,limit:any = null,offset:any = null){
    const ans = await this.service.searchByOneOfMultiFields(fields,txt,limit,offset);
    console.log('ans2: ',ans)
    return ans;
  }
  async deleteByElasticId(id: string) {
    this.service.deleteDocumentByElasticId( id);
  }
  async deleteByField(field: string, value: string|boolean) {
    this.service.deleteByField(field, value);
  }
  async deleteByMultipleFields(deleteObj: any) {
    this.service.deleteByMultipleFields(deleteObj);
  }
}
